//
//  ARService+Tracker.h
//  AppRelay
//
//  Created by Sebastien Morel on 13-03-22.
//  Copyright (c) 2013 WhereCloud Inc. All rights reserved.
//

#import <StoreKit/StoreKit.h>
#import "ARService.h"

typedef NS_OPTIONS(NSUInteger, ARTimedEventOptions) {
    ARTimedEventOptionNone                = 0,
    ARTimedEventOptionPauseOnInactive     = 1 << 0,
    ARTimedEventOptionStopOnBackground    = 1 << 1,
    ARTimedEventOptionRestartOnForeground = 1 << 2,
    ARTimedEventOptionDefault = (ARTimedEventOptionPauseOnInactive | ARTimedEventOptionStopOnBackground | ARTimedEventOptionRestartOnForeground)
};

typedef NS_ENUM(NSInteger, ARTimedEventState) {
    ARTimedEventStateStart,
    ARTimedEventStateStop
};

/**
 */
@interface ARService (Tracker)

/**
 */
- (void)registerPushDeviceToken:(NSData*)token;

///-----------------------------------
/// @name Tracking
///-----------------------------------

/**
 */
- (void)trackEvent:(NSString *)name properties:(NSDictionary *)properties;

/** returns NO if an event with the specified type has previously been registered.
 propertiesBlock allows to customize the properties when the tracker will stop/restart the event automatically depending on the options you specify.
 */
- (BOOL)trackTimedEvent:(NSString *)name options:(ARTimedEventOptions)options propertiesBlock:(NSDictionary *(^)(ARTimedEventState state, NSDictionary *previousProperties))propertiesBlock;

/** returns NO if an event with the specified type has previously been registered
 */
- (BOOL)trackTimedEvent:(NSString *)name options:(ARTimedEventOptions)options properties:(NSDictionary *)properties;

/** returns NO if an event with the specified type has previously been registered.
 propertiesBlock allows to customize the properties when the tracker will stop/restart the event automatically depending on the options you specify.
 */
- (BOOL)trackTimedEvent:(NSString *)name propertiesBlock:(NSDictionary *(^)(ARTimedEventState state, NSDictionary *previousProperties))propertiesBlock;

/** returns NO if an event with the specified type has previously been registered
 */
- (BOOL)trackTimedEvent:(NSString *)name properties:(NSDictionary *)properties;

/** returns -1 if the event is no more registered
 */
- (NSTimeInterval)stopTimedEvent:(NSString *)name properties:(NSDictionary *)properties;

/** returns -1 if the event is no more registered
 */
- (NSTimeInterval)stopTimedEvent:(NSString *)name;

/**
 */
- (void)trackPaymentTransaction:(SKPaymentTransaction *)paymentTransaction product:(SKProduct *)product;

@end
