//
//  ARApplication.h
//  AppRelay
//
//  Created by Sebastien Morel on 12-07-03.
//  Copyright (c) 2012 WhereCloud Inc. All rights reserved.
//

#import <UIKit/UIKit.h>

#import "ARService.h"
#import "ARService+PushNotification.h"

/** By inheriting your AppDelegate by ARApplication, the management of the ARService is done for you.
 You just have to implement the AppRelayAPIKey method in your AppDelegate.m file to return your API Key.
 */
@interface ARApplication : UIResponder <UIApplicationDelegate>

/** Returns the AppRelay API Key.
 */
- (NSString*)AppRelayAPIKey;

/** Returns the AppRelay Bundle Id.
 */
- (NSString*)AppRelayBundleId;

/** Returns whether or not the Application enables the campaigns.
 */
- (BOOL)AppRelayCampaignsEnabled;

/** Returns whether or not the Application enables the push api.
 */
- (BOOL)AppRelayPushApiEnabled;

/** Returns whether or not the Application enables the crash reports.
 */
- (BOOL)AppRelayCrashReportsEnabled;

/** Call this method whenever you'd like to restart the service. When the config changes for example and has an impact on service Urls or bundle ids.
 */
- (void)restartAppRelayService;

/** Overload this method to present Topic view controller or download the JSON content when a remote notification is received
 */
- (void)didReceivePushNotification:(ARPushNotification*)notification;

/** Overload this method to get notified of possible silent errors in the sdk.
 */
- (void)didReceiveErrorWithCategory:(NSString*)category error:(NSError*)error;

@end
