//
//  ARService+PushNotification.h
//  AppRelay
//
//  Created by Sebastien Morel on 13-03-22.
//  Copyright (c) 2013 WhereCloud Inc. All rights reserved.
//

#import "ARService.h"

typedef NS_ENUM(NSInteger, ARTopicType){
	ARTopicTypeCampaign = 0,
	ARTopicTypeJSON     = 1
};

/**
 */
@interface ARPushNotification : NSObject

/**
 */
@property(nonatomic,retain, readonly) NSString* title;

/**
 */
@property(nonatomic,retain, readonly) NSString* sound;

/**
 */
@property(nonatomic,retain, readonly) NSString* topicUuid;

/**
 */
@property(nonatomic,retain, readonly) NSString* messageUuid;

/**
 */
@property(nonatomic,assign, readonly) ARTopicType topicType;

/**
 */
@property(nonatomic,assign, readonly) BOOL pushNotificationDidOpenApplication;

@end



/**
 */
@interface ARService (PushNotification)

///-----------------------------------
/// @name Managing Push Notifications
///-----------------------------------

/**
 */
- (void)handleApplication:(UIApplication*)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions;

/**
 */
- (void)handleApplicationDidBecomeActive:(UIApplication*)application;

/**
 */
- (void)handleApplication:(UIApplication*)application didRegisterForRemoteNotificationsWithDeviceToken:(NSData*)apnsToken;

/**
 */
- (void)handleApplication:(UIApplication*)application didReceiveRemoteNotification:(NSDictionary*)userInfo pushNotificationDidOpenApplication:(BOOL)pushNotificationDidOpenApplication;

/**
 */
@property(nonatomic,copy) void(^didReceivePushNotificationBlock)(ARPushNotification* notification);


///-----------------------------------
/// @name Ballista Push Api
///-----------------------------------

/*
 */
- (void)subscribeUserToTopicNamed:(NSString*)topicName label:(NSString*)label completionBlock:(void(^)(NSError* error))completionBlock;

/*
 */
- (void)unsubscribeUserFromTopicNamed:(NSString*)topicName completionBlock:(void(^)(NSError* error))completionBlock;

/*
 */
- (void)unsubscribeUserFromAllTopicsWithCompletionBlock:(void(^)(NSError* error))completionBlock;

/**
 */
- (void)fetchSubscribedTopicsWithCompletionBlock:(void(^)(NSArray* topicNames, NSArray* topicLabels, NSError* error))completionBlock;

/**
 */
- (void)fetchJSONMessageWithTopicUuid:(NSString*)topicUuid messageUuid:(NSString*)messageUuid completionBlock:(void(^)(NSDictionary* json, NSError* error))completionBlock;

/**
 */
- (void)sendPushNotificationWithTopics:(NSArray*)topics localizedMessage:(NSDictionary*)localizedMessage defaultLanguage:(NSString*)defaultLanguage payload:(NSDictionary*)payload completionBlock:(void(^)(NSInteger numberOfUsers, NSError* error))completionBlock;

/**
 */
- (void)sendPushNotificationWithTopics:(NSArray*)topics sound:(NSString*)sound localizedMessage:(NSDictionary*)localizedMessage defaultLanguage:(NSString*)defaultLanguage payload:(NSDictionary*)payload completionBlock:(void(^)(NSInteger numberOfUsers, NSError* error))completionBlock;


@end
